@@ -1,11 +1,22 @@
 <?php
+/**
+ *
+ * @package MediaWiki
+ * @subpackage SpecialPage
+ */
+
+/**
+ *
+ */
 require_once( "SpecialRecentchanges.php" );
 require_once( "WatchedItem.php" );
 
-function wfSpecialWatchlist()
-{
-	global $wgUser, $wgOut, $wgLang, $wgTitle, $wgMemc, $wgRequest, $wgLoadBalancer;
-	global $wgUseWatchlistCache, $wgWLCacheTimeout, $wgDBname, $wgIsMySQL;
+/**
+ * constructor
+ */
+function wfSpecialWatchlist() {
+	global $wgUser, $wgOut, $wgLang, $wgTitle, $wgMemc, $wgRequest;
+	global $wgUseWatchlistCache, $wgWLCacheTimeout, $wgDBname;
 	$fname = "wfSpecialWatchlist";
 
 	$wgOut->setPagetitle( wfMsg( "watchlist" ) );
@@ -14,7 +25,7 @@ function wfSpecialWatchlist()
 	$wgOut->setRobotpolicy( "noindex,nofollow" );
 
 	$specialTitle = Title::makeTitle( NS_SPECIAL, "Watchlist" );
-	
+
 	$uid = $wgUser->getID();
 	if( $uid == 0 ) {
 		$wgOut->addHTML( wfMsg( "nowatchlist" ) );
@@ -54,19 +65,19 @@ function wfSpecialWatchlist()
 			return;
 		}
 	}
-	
-	$wgLoadBalancer->force(-1);
-	$sql = "SELECT COUNT(*) AS n FROM watchlist WHERE wl_user=$uid";
-	$res = wfQuery( $sql, DB_READ );
-	$s = wfFetchObject( $res );
+
+	$dbr =& wfGetDB( DB_SLAVE );
+	extract( $dbr->tableNames( 'cur', 'watchlist', 'recentchanges' ) );
+
+	$sql = "SELECT COUNT(*) AS n FROM $watchlist WHERE wl_user=$uid";
+	$res = $dbr->query( $sql, $fname );
+	$s = $dbr->fetchObject( $res );
 	$nitems = $s->n;
-	$wgLoadBalancer->force(0);
 	if($nitems == 0) {
         $wgOut->addHTML( wfMsg( "nowatchlist" ) );
         return;
 	}
 	
-	$wgLoadBalancer->force(-1);
 	if ( is_null( $days ) ) {
 		$big = 1000;
 		if($nitems > $big) {
@@ -78,35 +89,38 @@ function wfSpecialWatchlist()
 	} else {
 		$days = floatval($days);
 	}
-	
+
 	if ( $days <= 0 ) {
 		$docutoff = '';
 		$cutoff = false;
 		$npages = wfMsg( "all" );
 	} else {
-	        $docutoff = "AND cur_timestamp > '" .
-		  ( $cutoff = wfUnix2Timestamp( time() - intval( $days * 86400 ) ) )
-		  . "'";
-	        $sql = "SELECT COUNT(*) AS n FROM cur WHERE cur_timestamp>'$cutoff'";
-		$res = wfQuery( $sql, DB_READ );
-		$s = wfFetchObject( $res );
+		$cutoff = $dbr->timestamp( time() - intval( $days * 86400 ) );
+
+		// Excessively expensive query removed and replace with an estimate that's roughly the same on en.wikipedia.org
+		// Query below was more expensive than the real watchlist queries
+		/*
+		$docutoff = "AND cur_timestamp > '$cutoff'";
+		$sql = "SELECT COUNT(*) AS n FROM $cur WHERE cur_timestamp>'$cutoff'";
+		$res = $dbr->query( $sql, $fname );
+		$s = $dbr->fetchObject( $res );
 		$npages = $s->n;
-		
+		*/
+		$npages = 40000 * $days;
 	}
-	
+
 	if(isset($_REQUEST['magic'])) {
 		$wgOut->addHTML( wfMsg( "watchlistcontains", $wgLang->formatNum( $nitems ) ) .
 			"<p>" . wfMsg( "watcheditlist" ) . "</p>\n" );
-		
+
 		$wgOut->addHTML( "<form action='" .
 			$specialTitle->escapeLocalUrl( "action=submit" ) .
 			"' method='post'>\n" .
 			"<ul>\n" );
-		$sql = "SELECT wl_namespace,wl_title FROM watchlist WHERE wl_user=$uid";
-		$res = wfQuery( $sql, DB_READ );
-
+		$sql = "SELECT wl_namespace,wl_title FROM $watchlist WHERE wl_user=$uid";
+		$res = $dbr->query( $sql, $fname );
 		$sk = $wgUser->getSkin();
-		while( $s = wfFetchObject( $res ) ) {
+		while( $s = $dbr->fetchObject( $res ) ) {
 			$t = Title::makeTitle( $s->wl_namespace, $s->wl_title );
 			if( is_null( $t ) ) {
 				$wgOut->addHTML( '<!-- bad title "' . htmlspecialchars( $s->wl_title ) . '" in namespace ' . IntVal( $s->wl_namespace ) . " -->\n" );
@@ -121,17 +135,16 @@ function wfSpecialWatchlist()
 			"<input type='submit' name='remove' value=\"" .
 			htmlspecialchars( wfMsg( "removechecked" ) ) . "\" />\n" .
 			"</form>\n" );
-		
-		$wgLoadBalancer->force(0);
+
 		return;
 	}
-	
+
 	# If the watchlist is relatively short, it's simplest to zip
 	# down its entirety and then sort the results.
-	
+
 	# If it's relatively long, it may be worth our while to zip
 	# through the time-sorted page list checking for watched items.
-	
+
 	# Up estimate of watched items by 15% to compensate for talk pages...
 	if( $cutoff && ( $nitems*1.15 > $npages ) ) {
 		$x = "cur_timestamp";
@@ -143,16 +156,16 @@ function wfSpecialWatchlist()
 		$z = "(wl_namespace=cur_namespace OR wl_namespace+1=cur_namespace)";
 	}
 
-	
+
 	$wgOut->addHTML( "<i>" . wfMsg( "watchdetails",
 		$wgLang->formatNum( $nitems ), $wgLang->formatNum( $npages ), $y,
 		$specialTitle->escapeLocalUrl( "magic=yes" ) ) . "</i><br />\n" );
-	 
-	$use_index=$wgIsMySQL?"USE INDEX ($x)":"";
+
+	$use_index = $dbr->useIndexClause( $x );
 	$sql = "SELECT
   cur_namespace,cur_title,cur_comment, cur_id,
   cur_user,cur_user_text,cur_timestamp,cur_minor_edit,cur_is_new
-  FROM watchlist,cur $use_index
+  FROM $watchlist,$cur $use_index
   WHERE wl_user=$uid
   AND $z
   AND wl_title=cur_title
@@ -160,8 +173,8 @@ function wfSpecialWatchlist()
   ORDER BY cur_timestamp DESC";
 
 
-	$res = wfQuery( $sql, DB_READ, $fname );
-	$numRows = wfNumRows( $res );
+	$res = $dbr->query( $sql, $fname );
+	$numRows = $dbr->numRows( $res );
 	if($days >= 1)
 		$note = wfMsg( "rcnote", $wgLang->formatNum( $numRows ), $wgLang->formatNum( $days ) );
 	elseif($days > 0)
@@ -174,37 +187,36 @@ function wfSpecialWatchlist()
 
 	if ( $numRows == 0 ) {
 		$wgOut->addHTML( "<p><i>" . wfMsg( "watchnochange" ) . "</i></p>" );
-		$wgLoadBalancer->force(0);
 		return;
 	}
 
 	$sk = $wgUser->getSkin();
-	$s = $sk->beginRecentChangesList();
+	$list =& new ChangesList( $sk );
+	$s = $list->beginRecentChangesList();
 	$counter = 1;
-	while ( $obj = wfFetchObject( $res ) ) {
+	while ( $obj = $dbr->fetchObject( $res ) ) {
 		# Make fake RC entry
 		$rc = RecentChange::newFromCurRow( $obj );
 		$rc->counter = $counter++;
-		$s .= $sk->recentChangesLine( $rc, true );
+		$s .= $list->recentChangesLine( $rc, true );
 	}
-	$s .= $sk->endRecentChangesList();
+	$s .= $list->endRecentChangesList();
 
-	wfFreeResult( $res );
+	$dbr->freeResult( $res );
 	$wgOut->addHTML( $s );
 
 	if ( $wgUseWatchlistCache ) {
 		$wgMemc->set( $memckey, $s, $wgWLCacheTimeout);
 	}
-	
-	$wgLoadBalancer->force(0);
+
 }
 
 
 function wlHoursLink( $h, $page ) {
-	global $wgUser, $wgLang;
+	global $wgUser, $wgLang, $wgContLang;
 	$sk = $wgUser->getSkin();
 	$s = $sk->makeKnownLink(
-	  $wgLang->specialPage( $page ),
+	  $wgContLang->specialPage( $page ),
 	  $wgLang->formatNum( $h ),
 	  "days=" . ($h / 24.0) );
 	return $s;
@@ -212,10 +224,10 @@ function wlHoursLink( $h, $page ) {
 
 
 function wlDaysLink( $d, $page ) {
-	global $wgUser, $wgLang;
+	global $wgUser, $wgLang, $wgContLang;
 	$sk = $wgUser->getSkin();
 	$s = $sk->makeKnownLink(
-	  $wgLang->specialPage( $page ),
+	  $wgContLang->specialPage( $page ),
 	  ($d ? $wgLang->formatNum( $d ) : wfMsg( "all" ) ), "days=$d" );
 	return $s;
 }
