@@ -13,8 +13,8 @@
 	NS_TALK				=> "Diskuse", # neb diskutuj?
 	NS_USER				=> "Wikipedista",
 	NS_USER_TALK		=> "Wikipedista_diskuse",
-	NS_WIKIPEDIA		=> "Wikipedie",
-	NS_WIKIPEDIA_TALK	=> "Wikipedie_diskuse",
+	NS_PROJECT			=> "Wikipedie",
+	NS_PROJECT_TALK		=> "Wikipedie_diskuse",
 	NS_IMAGE			=> "Soubor",
 	NS_IMAGE_TALK		=> "Soubor_diskuse",
 	NS_MEDIAWIKI		=> "MediaWiki",
@@ -27,8 +27,6 @@
 	NS_CATEGORY_TALK	=> "Kategorie_diskuse",
 ) + $wgNamespaceNamesEn;
 
-# Zdědit apriorní preference: wgDefaultUserOptionsEn
-
 /* private */ $wgQuickbarSettingsCs = array(
 	"Žádný", "Leží vlevo", "Leží vpravo", "Visí vlevo"
 );
@@ -42,44 +40,14 @@
 	'davinci' => "DaVinci",
 	'mono' => "Mono",
 	'monobook' => "MonoBook",
- "myskin" => "MySkin" 
+	'myskin' => "MySkin" 
 );
 
-/* private */ $wgUserTogglesCs = array(
-	"hover"		=> "Ukázat odkazovou adresu (hoverbox) nad wikiovými odkazy",
-	"underline" => "Podtrhnout odkazy",
-	"highlightbroken" => "Začervenit odkazy na neexistující stránky",
-	"justify"	=> "Zarámovat řádky",
-	"hideminor" => "Ukrýt malé redakční úpravy <i>Poslední změny</i>",
-	"numberheadings" => "Automaticky spočítat sekce",
-	"showtoolbar" => "Show edit toolbar",
-	"rememberpassword" => "Pamatovat si mé heslo od návštěvy k návětěvě",
-	"editwidth" => "Redakční okno roztáhnout na celou šíři.",
-	"editondblclick" => "Redigovat dvojím kliknutím (JavaScript)",
-	"watchdefault" => "Náhled na nové a modifikované články",
-	"minordefault" => "Mark all edits minor by default" #TRADUKU MIN
-);
 
 # Se eble, trovu Chehxajn libroservojn traserceblaj lau ISBN
 # $wgBookstoreListCs = ..
-
-# Note capitalization; also some uses may require addition of final -n
-/* private */ $wgWeekdayNamesCs = array(
-	"neděle", "pondělí", "úterý", "středa" , "čtvrtek",
-	"pátek", "sobota"
-);
-
-# Double-check capitalization
-/* private */ $wgMonthNamesCs = array(
-	"leden", "únor", "březen", "duben", "květen", "červen",
-	"červenec", "srpen", "září", "říjen", "listopad",
-	"prosinec"
-);
-
-# There are no month abbreviations in Czech language.
-/* private */ $wgMonthAbbreviationsCs = array(
-	"1.", "2.", "3.", "4.", "5.", "6.",
-	"7.", "8.", "9.", "10.", "11.", "12."
+/* private */ $wgBookstoreListCs = array(
+	'Národní knihovna' => 'http://sigma.nkp.cz/F/?func=find-a&find_code=WRD&request=&request_op=AND&find_code=WAU&request=&request_op=AND&find_code=WTL&request=&request_op=AND&find_code=WYR&request=&request_op=AND&find_code=WPB&request=&request_op=AND&find_code=ISN&request=$1'
 );
 
 # All special pages have to be listed here: a description of ""
@@ -88,6 +56,7 @@
 #
 # *Neměnit jména v levém sloupci, jsou to interní jména programových funkcí. Pravý sloupec  obsahuje několik mezer, které mají tak zůstat, aby se tyto funkce nezařadily do seznamu speciálních stránek.
 /* private */ $wgValidSpecialPagesCs = array(
+
 	"Userlogin"		=> "",
 	"Userlogout"	=> "",
 	"Preferences"	=> "Změnit moje uživatelské preference", 
@@ -136,14 +105,62 @@
 );
 
 /* private */ $wgAllMessagesCs = array(
+'special_version_prefix' => '',
+'special_version_postfix' => '',
+# User Toggles
+"tog-hover"		=> "Ukázat odkazovou adresu (hoverbox) nad wikiovými odkazy",
+"tog-underline" => "Podtrhnout odkazy",
+"tog-highlightbroken" => "Začervenit odkazy na neexistující stránky",
+"tog-justify"	=> "Zarámovat řádky",
+"tog-hideminor" => "Ukrýt malé redakční úpravy <i>Poslední změny</i>",
+"tog-numberheadings" => "Automaticky spočítat sekce",
+"tog-showtoolbar" => "Show edit toolbar",
+"tog-rememberpassword" => "Pamatovat si mé heslo od návštěvy k návětěvě",
+"tog-editwidth" => "Redakční okno roztáhnout na celou šíři.",
+"tog-editondblclick" => "Redigovat dvojím kliknutím (JavaScript)",
+"tog-watchdefault" => "Náhled na nové a modifikované články",
+"tog-minordefault" => "Mark all edits minor by default",  #TRADUKU MIN
+
+# Dates
+'sunday' => "neděle",
+'monday' => "pondělí",
+'tuesday' => "úterý",
+'wednesday' => "středa",
+'thursday' => "čtvrtek",
+'friday' => "pátek",
+'saturday' => "sobota",
+'january' => "leden",
+'february' => "únor",
+'march' => "březen",
+'april' => "duben",
+'may_long' => "květen",
+'june' => "červen",
+'july' => "červenec",
+'august' => "srpen",
+'september' => "září",
+'october' => "říjen",
+'november' => "listopad",
+'december' => "prosinec",
+'jan' => "1.",
+'feb' => "2.",
+'mar' => "3.",
+'apr' => "4.",
+'may' => "5.",
+'jun' => "6.",
+'jul' => "7.",
+'aug' => "8.",
+'sep' => "9.",
+'oct' => "10.",
+'nov' => "11.",
+'dec' => "12.",
 
 # Části textu používané různými stránkami:
 #
 # Písmena, která se mají objevit jako část odkazu ve formě "[[jazyk]]y" atd:
-"linktrail"     => "/^([a-z]+)(.*)$/sD",
+"linktrail"     => "/^((?:[a-z]|á|č|ď|é|ě|í|ň|ó|ř|š|ť|ú|ů|ý|ž)+)(.*)$/sD",
 "mainpage"		=> "Hlavní strana",
 "about"			=> "Úvod",
-"aboutwikipedia" => "O Wikipedii", #FIXME
+"aboutsite"      => "O Wikipedii", #FIXME
 "aboutpage"		=> "Wikipedie:Úvod",
 "help"			=> "Nápověda",
 "helppage"		=> "Wikipedie:Nápověda",
@@ -166,7 +183,7 @@
 "currentevents" => "Aktuality", #FIXME - Novinky? Aktuální novinky? Aktuální události?
 "errorpagetitle" => "Chyba", #FIXME - Arero? ;)
 "returnto"		=> "Vrať se na $1.",
-"fromwikipedia"	=> "Z Wikipedie, otevřené encyklopedie.",
+"tagline"      	=> "Z Wikipedie, otevřené encyklopedie.",
 "whatlinkshere"	=> "Sem odkazy", #FIXME: cu ligantaj?
 "help"			=> "Nápověda",
 "search"		=> "Hledej",
@@ -209,7 +226,7 @@
 #
 "error"         => "Chyba",
 "databaseerror" => "Databázová chyba",
-"dberrortext"	=> "Syntaktická chyba se stala při dotazu na databázi. Možná ji způsobila nedovolená otázka. (viz $1), nebo to indikuje chybu v programovém vybavení. Jako poslední jste volil(a) otázku:
+"dberrortext"	=> "Syntaktická chyba se stala při dotazu na databázi.  Jako poslední jste volil(a) otázku:
 <blockquote><tt>$1</tt></blockquote>
 z funkce \"<tt>$2</tt>\". 
 MySQL vrátil chybu  \"<tt>$3: $4</tt>\".",
@@ -247,8 +264,8 @@ Můžete pracovat ve Wikipedii anonymně, nebo se přihlásit znovu jako stejný
 "yourpasswordagain" => "Napište heslo znovu",
 "newusersonly"	=> " (pouze noví uživatelé)",
 "remembermypassword" => "Pamatuj si mé heslo od seance k seanci.",
-"loginproblem"	=> "<b>Nastal problém při vašem přihlášení.</b><br>Zkuste to znovu!",
-"alreadyloggedin" => "<font color=\"red\"><b>Uživateli $1, již jste přihlášen!</b></font><br>\n",
+"loginproblem"	=> "<b>Nastal problém při vašem přihlášení.</b><br />Zkuste to znovu!",
+"alreadyloggedin" => "<font color=\"red\"><b>Uživateli $1, již jste přihlášen!</b></font><br />\n",
 
 "login"			=> "Přihlašte se", #FIXME, what exactly do the following go to?
 "userlogin"		=> "Přihlašte se",
@@ -284,7 +301,7 @@ Doporučujeme, abyste se nyní přihlásil a raději změnil heslo.", #FIXME
 "showpreview"	=> "Ukaž náhled", #FIXME eh?
 "blockedtitle"	=> "Uživatel odblokován", #FIXME cu 'Konto forbarita'?
 "blockedtext"	=> "Váš účet nebo IP-adresa byly odblokovány osobou ,
-která popsala příčinu takto:<br><p>Máte právo se spojit se správcem systému a prodiskutovat odblokování.", #FIXME - sistemestro?
+která popsala příčinu takto:<br /><p>Máte právo se spojit se správcem systému a prodiskutovat odblokování.", #FIXME - sistemestro?
 "newarticle"	=> "(Nový)",
 "newarticletext" => "Vložte sem text nového článku.", #FIXME?
 "noarticletext" => "(Článek zatím neobsahuje text)", #FIXME
@@ -329,8 +346,6 @@ která popsala příčinu takto:<br><p>Máte právo se spojit se správcem syst
 # Search results
 #
 "searchresults" => "Výsledek hledání",
-"searchhelppage" => "Wikipedie:Hledání",
-"searchingwikipedia" => "Hledání ve Wikipedii",
 "searchresulttext" => "Nápovědu, jak účinně hledat ve Wikipedii, čtěte na  .",
 "searchquery"	=> "Zadání pro vyhledávání \"$1\"",
 "badquery"		=> "Zkreslené zadání pro vyhledávání",
@@ -349,8 +364,8 @@ která popsala příčinu takto:<br><p>Máte právo se spojit se správcem syst
 "nonefound"		=> "<strong>Poznámka</strong>: neúspěšné hledání zaviňuje často zadání slov, které nejsou v indexu, nebo mnoha slov najednou (jen stránky, které obsahují všechna zadaná slova, se objeví ve výsledku).",
 "powersearch" => "Sercu",
 #"powersearchtext" => "Hledej"
-#Sercu en sekcioj: :<br>
-#<br>
+#Sercu en sekcioj: :<br />
+#<br />
 # Kun alidirektiloj &nbsp; Sercu  ",
 
 # Preferences page
@@ -358,7 +373,7 @@ která popsala příčinu takto:<br><p>Máte právo se spojit se správcem syst
 "preferences"	=> "Preference",
 "prefsnologin" => "Dosud nepřihlášen!",
 "prefsnologintext"	=> "Určite <a href=\"" .
-  wfLocalUrl( "Special:Userlogin" ) . "\">se přihlaste</a>
+  "{{localurle:Special:Userlogin}}\">se přihlaste</a>
 dříve než je možno měnit priority.",
 "prefslogintext" => "Přihlásil jste se \"$1\".
 Vaše interní identifikační číslo je  .",
@@ -425,29 +440,29 @@ Také se podívejte na
 "reuploaddesc"	=> "Vrať se k načtení.",
 "uploadnologin" => "Nepřihlášený",
 "uploadnologintext"	=> "Musíte mít účet a <a href=\"" .
-  wfLocalUrl( "Speciala:Userlogin" ) . "\">přihlaste se</a>
+  "{{localurle:Speciala:Userlogin}}\">přihlaste se</a>
 pro načtení souboru.",
 "uploadfile"	=> "Načti soubor",
 "uploaderror"	=> "Při načítání došlo k chybě",
-"uploadtext"	=> "Pro prohlížení a hledání již načtených souborů, jděte na  <a href=\"" . wfLocalUrl( "Special:Imagelist" ) .
-"\">seznam načteného</a>.
-Každé načtení a odstranění je registrováno u  <a href=\"" .
-wfLocalUrl( "Wikipedie:Načtení_log" ) ."\">Načtení_log</a>.</p>
+"uploadtext"	=> "Pro prohlížení a hledání již načtených souborů, jděte na
+[[Special:Imagelist|seznam načteného]].
+Každé načtení a odstranění je registrováno u
+[[Project:Načtení_log|Načtení_log]].
 
+Použij tento formulář pro načtení nového obrázku nebo jiných souborů jako ilustrací ke svým článkům. U běžných prohlížečů se dole objeví buton \"Procházet...\" apod; tím se otevřou adresáře tvého pevného disku, kde si vybereš svůj soubor, jehož název vyplní pole vedle butonu; musíš také potvrdit prohlášení, že neporušuješ ničí copyright. Vlastní načtení provedeš kliknutím na buton \"Načti\". Může to trvat i delší dobu, pokud je soubor velký a počítač pomalý.
 
-<p>Použij tento formulář pro načtení nového obrázku nebo jiných souborů jako ilustrací ke svým článkům. U běžných prohlížečů se dole objeví buton \"Procházet...\" apod; tím se otevřou adresáře tvého pevného disku, kde si vybereš svůj soubor, jehož název vyplní pole vedle butonu; musíš také potvrdit prohlášení, že neporušuješ ničí copyright. Vlastní načtení provedeš kliknutím na buton \"Načti\". Může to trvat i delší dobu, pokud je soubor velký a počítač pomalý.</p>
-
-<p>Wikipedie upřednostňuje formát JPEG pro fotografie,
+Wikipedie upřednostňuje formát JPEG pro fotografie,
 PNG pro grafiku, diagramy, apod.; a OGG pro zvukové nahrávky.
 Pojmenuj svůj soubor informativním způsobem, aby se vyloučila nedorozumění.
 Pro vložení obrázku do článku napiš odkaz ve formě
-<b>[[obrázek:soubor.jpg]]</b> nebo <b>[[image:obraz.png|text pro prohlížeče bez grafiky]]</b>,
-nebo <b>[[soubor:soubor.ogg]]</b> por sounds.</p>
+'''<nowiki>[[obrázek:soubor.jpg]]</nowiki>''' nebo
+'''<nowiki>[[obrázek:obraz.png|text pro prohlížeče bez grafiky]]</nowiki>''', nebo
+'''<nowiki>[[soubor:soubor.ogg]]</nowiki>''' por sounds.
 
-<p>Všimni si, že články ve Wikipedii mohou redigovat i ostatní wikipediisté. Mohou přidávat, nahrazovat, i odstraňovat, pokud to prospěje encyklopedii. Pokud někdo bude zlomyslně poškozovat soubory jiných autorů,
-může mu být zablokován přístup k redigování.</p>",
-"uploadlog"		=> "kniha nahrávek ",
-"uploadlogpage" => "kniha_nahrávek ",
+Všimni si, že články ve Wikipedii mohou redigovat i ostatní wikipediisté. Mohou přidávat, nahrazovat, i odstraňovat, pokud to prospěje encyklopedii. Pokud někdo bude zlomyslně poškozovat soubory jiných autorů,
+může mu být zablokován přístup k redigování.",
+"uploadlog"		=> "kniha nahrávek",
+"uploadlogpage" => "kniha_nahrávek",
 "uploadlogpagetext" => "Přehled naposledy načtených souborů. Všechny časové údaje se ukazují podle časového pásma UTC.
 <ul>
 </ul>
@@ -491,7 +506,7 @@ Věnuj pozornost následujícímu odkazu: ($2) na stránku popisu a napiš pár
 "deleteimg"		=> "for",
 "deleteimgcompletely"		=> "for",
 "imghistlegend" => "(nun) = toto je současná verze souboru, (for) = odstranit tuto starou verzi, (res) = obnovit starou verzi.
-<br><i>Click on date to see image uploaded on that date</i>.",
+<br /><i>Click on date to see image uploaded on that date</i>.",
 "imagelinks"	=> "Odkazy k souboru ",
 "linkstoimage"	=> "K souboru odkazují tyto stránky:",
 "nolinkstoimage" => "Žádná stránka neodkazuje na tento soubor.",
@@ -517,9 +532,9 @@ To je v průměru jedna stránka na <b></b> návštěv, a na <b></b> redakcí.",
 "maintenancebacklink"	=> "Návrat k nástrojům",
 "disambiguations"	=> "Špatně odkázané oddělovače ",
 "disambiguationspage"	=> "Wikipedie:Oddělovače",
-"disambiguationstext"	=> "Tyto stránky odkazují na <i>stránkový oddělovač</i>. Měly by místo toho odkazovat na správný subjekt.<br>Bereme do úvahy stránky, které odkazují na oddělovač.<br>Odkazy na sekci nečlánkových souborů <i>ne</i> se zapisují zde.",
+"disambiguationstext"	=> "Tyto stránky odkazují na <i>stránkový oddělovač</i>. Měly by místo toho odkazovat na správný subjekt.<br />Bereme do úvahy stránky, které odkazují na oddělovač.<br />Odkazy na sekci nečlánkových souborů <i>ne</i> se zapisují zde.",
 "doubleredirects"	=> "Dvojité přesměrování",
-"doubleredirectstext"	=> "<b>Pozor:</b> Může se stát, že tento seznam bude obsahovat falešné pozitivy. Všeobecně to znamená, že existuje další text s odkazy po #REDIERCT.<br>
+"doubleredirectstext"	=> "<b>Pozor:</b> Může se stát, že tento seznam bude obsahovat falešné pozitivy. Všeobecně to znamená, že existuje další text s odkazy po #REDIERCT.<br />
 Každý řádek ukazuje odkaz k prvnímu a druhému přesměrování, plus první řádek textu druhého přesměrování, který všeobecně ukazuje \"skutečný\" hlavní článek, na který odkazuje první přesměrování.",
 "brokenredirects"	=> "Přerušené přesměrování",
 "brokenredirectstext"	=> "Tato přesměrování se vztahují na neexistující články.",
@@ -563,9 +578,9 @@ Každý řádek ukazuje odkaz k prvnímu a druhému přesměrování, plus prvn
 #
 "mailnologin"	=> "Žádná adresa k zaslání",
 "mailnologintext" => "Určitě uveď <a href=\"" .
-  wfLocalUrl( "Speciala:Userlogin" ) . "\">jméno</a>
+  "{{localurle:Speciala:Userlogin}}\">jméno</a>
 a měj platnou e-mailovou adresu ve svých <a href=\"" .
-  wfLocalUrl( "Speciala:Preferences" ) . "\">preferencích</a>
+  "{{localurle:Speciala:Preferences}}\">preferencích</a>
 abys mohl mailovat jiným wikipediistům.",
 "emailuser"		=> "Pošli mail",
 "emailpage"		=> "Pošli mail",
@@ -591,13 +606,13 @@ pošty, aby adresát mohl odpovědět.",
 "nowatchlist"	=> "Zatím jsi neuvedl žádné oblíbené stránky.",
 "watchnologin"	=> "Neuvedeno jméno",
 "watchnologintext"	=> "Nutno uvést <a href=\"" .
-  wfLocalUrl( "Speciala:Userlogin" ) . "\">jméno</a>
+  "{{localurle:Speciala:Userlogin}}\">jméno</a>
 pro aktivaci tvých oblíbených stránek.",
 "addedwatch"	=> "Přidáno k oblíbeným",
 "addedwatchtext" => "Stránka \"$1\" je přidána k tvým <a href=\"" .
-  wfLocalUrl( "Speciala:Watchlist" ) . "\">oblíbeným</a>.
+  "{{localurle:Speciala:Watchlist}}\">oblíbeným</a>.
 Budoucí změny této stránky se objeví <b>tučně</b> v  <a href=\"" .
-  wfLocalUrl( "Speciala:Recentchanges" ) . "\">seznamu Poslední Změny </a>,
+  "{{localurle:Speciala:Recentchanges}}\">seznamu Poslední Změny </a>,
 a bude počítány v seznamu tvých Oblíbených.
 
 <p>Pokud později budeš chtít odstranit stránku ze seznamu Oblíbených, klikni na \"Ignoruj stránku \" v liště nástrojů.",
@@ -613,7 +628,7 @@ a bude počítány v seznamu tvých Oblíbených.
 "confirm"		=> "Potvrdit",
 "confirmdelete" => "Potvrdit odstranění",
 "deletesub"		=> "(Odstraňuje se \"$1\")",
-"confirmdeletetext" => "Odstraníš článek nebo soubor a smažeš celou jeho historii z databáze.<br>
+"confirmdeletetext" => "Odstraníš článek nebo soubor a smažeš celou jeho historii z databáze.<br />
 Potvrď prosím, že to opravdu chceš, že si uvědomuješ důsledky a že dodržuješ [[Wikipedie:Pravidla o odstraňování]].",
 "confirmcheck"	=> "Ano, jsem naprosto jist, že chci toto odstranit.",
 "actioncomplete" => "Provedeno",
@@ -674,7 +689,7 @@ Níže objasni přesný důvod (např. uveď stránku, která se stala terčem v
 "noblockreason" => "Nutno uvést důvod zablokování.",
 "blockipsuccesssub" => "Úspěšné zablokování",
 "blockipsuccesstext" => "Adresa IP \"$1\" je zablokována.
-<br>Viz [[Special:Ipblocklist|seznam zablokování IP]].",
+<br />Viz [[Special:Ipblocklist|seznam zablokování IP]].",
 "unblockip"		=> "Zrušit blokování adresy IP",
 "unblockiptext"	=> "Tímto formulářem možno obnovit právo blokované adresy IP opět přispívat do wikipedie.",
 "ipusubmit"		=> "Zrušit blokování adresy",
@@ -699,7 +714,7 @@ Níže objasni přesný důvod (např. uveď stránku, která se stala terčem v
 "lockdbsuccesssub" => "Databáze uzamknuta",
 "unlockdbsuccesssub" => "Databáze odemknuta",
 "lockdbsuccesstext" => "Databáze wikipedie je uzamknuta.
-<br>Nezapomeň ji odemknout po opravách.",
+<br />Nezapomeň ji odemknout po opravách.",
 "unlockdbsuccesstext" => "Databáze wikipedie je odemknuta.",
 
 # SQL query
@@ -722,7 +737,7 @@ Může to být drastická a nečekaná změna pro oblíbené stránky. Ujisti se
 "movearticle"	=> "Přesuň stránku",
 "movenologin"	=> "Neuvedeno přihlašovací jméno",
 "movenologintext" => "Musíš být přihlášeným uživatelem a <a href=\"" .
-  wfLocalUrl( "Speciala:Userlogin" ) . "\">uveď přihlašovací jméno</a>
+  "{{localurle:Speciala:Userlogin}}\">uveď přihlašovací jméno</a>
 abys mohl stránku přesunout.",
 "newtitle"		=> "Na nový název",
 "movepagebtn"	=> "Přesuň stránku",
@@ -774,29 +789,6 @@ class LanguageCs extends LanguageUtf8 {
 		return $wgSkinNamesCs;
 	}
 
-	function getUserToggles() {
-		global $wgUserTogglesCs;
-		return $wgUserTogglesCs;
-	}
-
-	function getMonthName( $key )
-	{
-		global $wgMonthNamesCs;
-		return $wgMonthNamesCs[$key-1];
-	}
-
-	function getMonthAbbreviation( $key )
-	{
-		global $wgMonthAbbreviationsCs;
-		return $wgMonthAbbreviationsCs[$key-1];
-	}
-
-	function getWeekdayName( $key )
-	{
-		global $wgWeekdayNamesCs;
-		return $wgWeekdayNamesCs[$key-1];
-	}
-
 	# Zdědit userAdjust()
  
 	# Datové a časové funkce možno upřesnit podle jazyka
