@@ -42,31 +42,7 @@
  "myskin" => "MySkin" 
 );
 
-/* private */ $wgMathNamesIa = array(
-	"Sempre produce PNG",
-	"HTML si multo simple, alteremente PNG",
-	"HTML si possibile, alteremente PNG",
-	"Lassa lo como TeX (pro navigatores in modo texto)",
-	"Recommendate pro navigatores moderne"
-);
 
-/* private */ $wgUserTogglesIa = array(
-	"hover"		=> "Evidentiar wikiligamines sub le ratto",
-	"underline" => "Sublinear ligamines",
-	"highlightbroken" => "Formatar ligamines rupte <a href=\"\" class=\"new\">assi</a> (alternativemente: assi<a href=\"\" class=\"internal\">?</a>).",
-	"justify"	=> "Justificar paragraphos",
-	"hideminor" => "Occultar modificationes recente minor",
-	"usenewrc" => "Modificationes recente meliorate (non functiona in tote le navigatores)",
-	"numberheadings" => "Numerar titulos automaticamente",
-	"showtoolbar" => "Show edit toolbar",
-	"rememberpassword" => "Recordar contrasigno inter sessiones (usa cookies)",
-	"editwidth" => "Cassa de redaction occupa tote le largor del fenestra",
-	"editondblclick" => "Duple clic pro modificar un pagina (usa JavaScript)",
-	"watchdefault" => "Poner articulos nove e modificate sub observation",
-	"minordefault" => "Marcar modificationes initialmente como minor",
-	"previewontop" => "Monstrar previsualisation ante le cassa de edition e non post illo"
-	
-);
 
 /* private */ $wgBookstoreListIa = array(
 	"AddALL" => "http://www.addall.com/New/Partner.cgi?query=$1&type=ISBN",
@@ -75,21 +51,6 @@
 	"Amazon.com" => "http://www.amazon.com/exec/obidos/ISBN=$1"
 );
 
-/* private */ $wgWeekdayNamesIa = array(
-	"dominica", "lunedi", "martedi", "mercuridi", "jovedi",
-	"venerdi", "sabbato"
-);
-
-/* private */ $wgMonthNamesIa = array(
-	"januario", "februario", "martio", "april", "maio", "junio",
-	"julio", "augusto", "septembre", "octobre", "novembre",
-	"decembre"
-);
-
-/* private */ $wgMonthAbbreviationsIa = array(
-	"jan", "feb", "mar", "apr", "mai", "jun", "jul", "aug",
-	"sep", "oct", "nov", "dec"
-);
 
 # All special pages have to be listed here: a description of ""
 # will make them not show up on the "Special Pages" page, which
@@ -143,13 +104,69 @@
 );
 
 /* private */ $wgAllMessagesIa = array(
+'special_version_prefix' => '',
+'special_version_postfix' => '',
+
+# User Toggles
+#
+
+"tog-hover"		=> "Evidentiar wikiligamines sub le ratto",
+"tog-underline" => "Sublinear ligamines",
+"tog-highlightbroken" => "Formatar ligamines rupte <a href=\"\" class=\"new\">assi</a> (alternativemente: assi<a href=\"\" class=\"internal\">?</a>).",
+"tog-justify"	=> "Justificar paragraphos",
+"tog-hideminor" => "Occultar modificationes recente minor",
+"tog-usenewrc" => "Modificationes recente meliorate (non functiona in tote le navigatores)",
+"tog-numberheadings" => "Numerar titulos automaticamente",
+"tog-showtoolbar" => "Show edit toolbar",
+"tog-rememberpassword" => "Recordar contrasigno inter sessiones (usa cookies)",
+"tog-editwidth" => "Cassa de redaction occupa tote le largor del fenestra",
+"tog-editondblclick" => "Duple clic pro modificar un pagina (usa JavaScript)",
+"tog-watchdefault" => "Poner articulos nove e modificate sub observation",
+"tog-minordefault" => "Marcar modificationes initialmente como minor",
+"tog-previewontop" => "Monstrar previsualisation ante le cassa de edition e non post illo",
+
+# dates
+#
+
+'sunday' => 'dominica',
+'monday' => 'lunedi',
+'tuesday' => 'martedi',
+'wednesday' => 'mercuridi',
+'thursday' => 'jovedi',
+'friday' => 'venerdi',
+'saturday' => 'sabbato',
+'january' => 'januario',
+'february' => 'februario',
+'march' => 'martio',
+'april' => 'april',
+'may_long' => 'maio',
+'june' => 'junio',
+'july' => 'julio',
+'august' => 'augusto',
+'september' => 'septembre',
+'october' => 'octobre',
+'november' => 'novembre',
+'december' => 'decembre',
+'jan' => 'jan',
+'feb' => 'feb',
+'mar' => 'mar',
+'apr' => 'apr',
+'may' => 'mai',
+'jun' => 'jun',
+'jul' => 'jul',
+'aug' => 'aug',
+'sep' => 'sep',
+'oct' => 'oct',
+'nov' => 'nov',
+'dec' => 'dec',
+
 
 # Bits of text used by many pages:
 #
 "linktrail"		=> "/^([a-z]+)(.*)\$/sD",
 "mainpage"		=> "Frontispicio",
 "about"			=> "A proposito",
-"aboutwikipedia" => "A proposito de Wikipedia",
+"aboutsite"      => "A proposito de Wikipedia",
 "aboutpage"		=> "Wikipedia:A_proposito",
 "help"			=> "Adjuta",
 "helppage"		=> "Wikipedia:Adjuta",
@@ -172,7 +189,7 @@
 "currentevents" => "Actualitates",
 "errorpagetitle" => "Error",
 "returnto"		=> "Retornar a $1.",
-"fromwikipedia"	=> "De Wikipedia, le encyclopedia libere.",
+"tagline"      	=> "De Wikipedia, le encyclopedia libere.",
 "whatlinkshere"	=> "Referentias a iste pagina",
 "help"			=> "Adjuta",
 "search"		=> "Recercar",
@@ -231,8 +248,6 @@ recognoscite per le systema de Wikipedia.",
 "error"			=> "Error",
 "databaseerror" => "Error de base de datos",
 "dberrortext"	=> "Occurreva un error de syntaxe in le consulta al base de datos.
-Isto pote deber se a un consulta non permittite (vide $5),
-o a un disfunction in le systema.
 Le ultime demanda inviate al base de datos esseva:
 <blockquote><tt>$1</tt></blockquote>
 de intra le function \"<tt>$2</tt>\".
@@ -286,8 +301,8 @@ Non oblida personalisar Wikipedia secundo tu preferentias.",
 "yourpasswordagain" => "Confirmar contrasigno",
 "newusersonly"	=> " (solmente pro nove usatores)",
 "remembermypassword" => "Recordar contrasigno inter sessiones.",
-"loginproblem"	=> "<b>Occurreva problemas pro initiar tu session.</b><br>Tenta de nove!",
-"alreadyloggedin" => "<font color=red><b>Usator $1, tu session ja es aperte!</b></font><br>\n",
+"loginproblem"	=> "<b>Occurreva problemas pro initiar tu session.</b><br />Tenta de nove!",
+"alreadyloggedin" => "<font color=red><b>Usator $1, tu session ja es aperte!</b></font><br />\n",
 
 "login"			=> "Aperir session",
 "userlogin"		=> "Aperir session",
@@ -328,7 +343,7 @@ Per favor initia un session post reciper lo.",
 "showpreview"	=> "Monstrar previsualisation",
 "blockedtitle"	=> "Le usator es blocate",
 "blockedtext"	=> "Tu nomine de usator o adresse de IP ha essite blocate per $1.
-Le motivo presentate es iste:<br>''$2''<p>Tu pote contactar $1 o un del altere
+Le motivo presentate es iste:<br />''$2''<p>Tu pote contactar $1 o un del altere
 [[Wikipedia:administratores|administratores]] pro discuter le bloco.",
 "newarticle"	=> "(Nove)",
 "newarticletext" =>
@@ -362,7 +377,7 @@ Si tu lo salvara, tote le modificationes facite post iste revision essera perdit
 considerate public secundo le terminos del Licentia de Documentation Libere GNU
 (vide plus detalios in $1).
 Si tu non vole que tu scripto sia modificate impietosemente e redistribuite
-a voluntate, alora non lo edita hic.<br>
+a voluntate, alora non lo edita hic.<br />
 Additionalmente, tu nos garanti que tu es le autor de tu contributiones,
 o que tu los ha copiate de un ressource libere de derectos.
 <strong>NON USA MATERIAL COPERITE PER DERECTOS DE AUTOR (COPYRIGHT) SIN AUTORISATION EXPRESSE!</strong>",
@@ -398,9 +413,7 @@ Verifica le URL que tu ha usate pro accessar iste pagina.\n",
 # Search results
 #
 "searchresults" => "Resultatos del recerca",
-"searchhelppage" => "Wikipedia:Recerca",
-"searchingwikipedia" => "Recerca in Wikipedia",
-"searchresulttext" => "Pro plus information super le recerca de Wikipedia, vide $1.",
+"searchresulttext" => "Pro plus information super le recerca de {{SITENAME}}, vide [[Project:Recerca|Recerca in {{SITENAME}}]].",
 "searchquery"	=> "Pro le consulta \"$1\"",
 "badquery"		=> "Consulta de recerca mal formate",
 "badquerytext"	=> "Impossibile processar tu consulta.
@@ -428,8 +441,8 @@ terminos de recerca (solmente le paginas que contine tote le terminos
 de recerca apparera in le resultato).",
 "powersearch" => "Recercar",
 "powersearchtext" => "
-Recerca in contextos :<br>
-$1<br>
+Recerca in contextos :<br />
+$1<br />
 $2 Listar redireciones &nbsp; Recercar pro $3 $9",
 
 
@@ -438,7 +451,7 @@ $2 Listar redireciones &nbsp; Recercar pro $3 $9",
 "preferences"	=> "Preferentias",
 "prefsnologin" => "Session non aperte",
 "prefsnologintext"	=> "Tu debe <a href=\"" .
-  wfLocalUrl( "Special:Userlogin" ) . "\">aperir un session</a>
+  "{{localurle:Special:Userlogin}}\">aperir un session</a>
 pro definir tu preferentias.",
 "prefslogintext" => "Tu es identificate como \"$1\".
 Tu numero interne de ID es $2.",
@@ -516,20 +529,21 @@ In ultra, lege iste [http://meta.wikipedia.org/wiki/Special:Recentchanges recent
 "reuploaddesc"	=> "Retornar al formulario de carga.",
 "uploadnologin" => "Session non aperte",
 "uploadnologintext"	=> "Tu debe <a href=\"" .
-  wfLocalUrl( "Special:Userlogin" ) . "\">aperir un session</a>
+  "{{localurle:Special:Userlogin}}\">aperir un session</a>
 pro poter cargar files.",
 "uploadfile"	=> "Cargar file",
 "uploaderror"	=> "Error de carga",
-"uploadtext"	=> "<strong>STOP!</strong> Ante cargar files al servitor,
-prende cognoscentia del <a href=\"" .
-wfLocalUrlE( "Wikipedia:Image_use_policy" ) . "\">politica de Wikipedia super le uso de imagines</a>,
+"uploadtext"	=> "'''STOP!''' Ante cargar files al servitor,
+prende cognoscentia del
+[[Project:Image_use_policy|politica de Wikipedia super le uso de imagines]],
 e assecura te de respectar lo.
-<p>Pro vider o recercar imagines cargate previemente,
-vade al <a href=\"" . wfLocalUrlE( "Special:Imagelist" ) .
-"\">lista de imagines cargate</a>.
-Cargas e eliminationes es registrate in le <a href=\"" .
-wfLocalUrlE( "Wikipedia:Upload_log" ) . "\">registro de cargas</a>.
-<p>Usa le formulario infra pro cargar nove files de imagine pro
+
+Pro vider o recercar imagines cargate previemente,
+vade al [[Special:Imagelist|lista de imagines cargate]].
+Cargas e eliminationes es registrate in le
+[[Project:Upload_log|registro de cargas]].
+
+Usa le formulario infra pro cargar nove files de imagine pro
 illustrar tu articulos.
 In le major parte del navigatores, tu videra un button \"Browse...\",
 que facera apparer le cassa de dialogo de apertura de files
@@ -541,14 +555,17 @@ del file.
 Preme le button \"Cargar\" pro initiar le transmission.
 Le carga pote prender alcun tempore si tu connexion al Internet
 es lente.
-<p>Le formatos preferite es JPEG pro imagines photographic,
+
+Le formatos preferite es JPEG pro imagines photographic,
 PNG pro designos e altere imagines iconic, e OGG pro sonos.
 Per favor, attribue nomines descriptive a tu files pro evitar
 confusion.
 Pro includer le imagine in un articulo, usa un ligamine in
-le forma <b>[[image:file.jpg]]</b> o <b>[[image:file.png|texto alternative]]</b>
-o <b>[[media:file.ogg]]</b> pro sonos.
-<p>Nota que, justo como occurre con le paginas de Wikipedia, alteros
+le forma '''<nowiki>[[image:file.jpg]]</nowiki>''' o
+'''<nowiki>[[image:file.png|texto alternative]]</nowiki>''' o
+'''<nowiki>[[media:file.ogg]]</nowiki>''' pro sonos.
+
+Nota que, justo como occurre con le paginas de Wikipedia, alteros
 pote modificar o eliminar le files cargate si illes considera que
 isto beneficia le encyclopedia, e tu pote haber tu derecto
 de carga blocate si tu abusa del systema.",
@@ -604,7 +621,7 @@ a su proposito.",
 "deleteimgcompletely"		=> "elim",
 "imghistlegend" => "Legend: (actu) = iste es le imagine actual, (elim) = elimina
 iste version antique, (rev) = reverte a iste version antique.
-<br><i>Clica super le data pro vider le imagine cargate in ille die.</i>",
+<br /><i>Clica super le data pro vider le imagine cargate in ille die.</i>",
 "imagelinks"	=> "Ligamines al imagine",
 "linkstoimage"	=> "Le paginas sequente se liga a iste imagine:",
 "nolinkstoimage" => "Necun pagina se liga a iste imagine.",
@@ -635,12 +652,12 @@ non preme \"Reload\" post cata item reparate. ;-)",
 "disambiguations"	=> "Paginas de disambiguation",
 "disambiguationspage"	=> "Wikipedia:Ligamines_a_paginas_de_disambiguation",
 "disambiguationstext"	=> "Le articulos sequente se liga a un <i>pagina de disambiguation</i>.
-Illos deberea ligar se directemente al topico appropriate.<br>
+Illos deberea ligar se directemente al topico appropriate.<br />
 Un pagina es tractate como un pagina de disambiguation si existe un ligamine
 a illo in $1. Ligamines de altere contextos <i>non</i> es listate hic.",
 "doubleredirects"	=> "Redirectiones duple",
 "doubleredirectstext"	=> "<b>Attention:</b> Iste lista pote continer items false.
-Illo generalmente significa que il ha texto additional con ligamines sub le prime #REDIRECT.<br>
+Illo generalmente significa que il ha texto additional con ligamines sub le prime #REDIRECT.<br />
 Cata linea contine ligamines al prime e secunde redirection, assi como le prime linea del
 secunde texto de redirection, generalmente exhibiente le articulo scopo \"real\",
 al qual le prime redirection deberea referer se.",
@@ -695,9 +712,9 @@ non debe esser interpretate como alcun appoio special.",
 #
 "mailnologin"	=> "Necun adresse de invio",
 "mailnologintext" => "Tu debe <a href=\"" .
-  wfLocalUrl( "Special:Userlogin" ) . "\">aperir un session</a>
+  "{{localurle:Special:Userlogin}}\">aperir un session</a>
 e haber un adresse de e-mail valide in tu <a href=\"" .
-  wfLocalUrl( "Special:Preferences" ) . "\">preferentias</a>
+  "{{localurle:Special:Preferences}}\">preferentias</a>
 pro inviar e-mail a altere usatores.",
 "emailuser"		=> "Inviar e-mail a iste usator",
 "emailpage"		=> "Inviar e-mail al usator",
@@ -724,14 +741,14 @@ o ha optate pro non reciper e-mail de altere usatores.",
 "nowatchlist"	=> "Tu non ha paginas sub observation.",
 "watchnologin"	=> "Session non aperte",
 "watchnologintext"	=> "Tu debe <a href=\"" .
-  wfLocalUrl( "Special:Userlogin" ) . "\">aperir un session</a>
+  "{{localurle:Special:Userlogin}}\">aperir un session</a>
 pro modificar tu lista de paginas sub observation.",
 "addedwatch"	=> "Ponite sub observation",
 "addedwatchtext" => "Le pagina \"$1\" es ora in tu <a href=\"" .
-  wfLocalUrl( "Special:Watchlist" ) . "\">lista de paginas sub observation</a>.
+  "{{localurle:Special:Watchlist}}\">lista de paginas sub observation</a>.
 Modificationes futur a iste pagina e su pagina de discussion associate essera listate la,
 e le pagina apparera <b>in nigretto</b> in le <a href=\"" .
-  wfLocalUrl( "Special:Recentchanges" ) . "\">lista de modificationes recente</a> pro
+  "{{localurle:Special:Recentchanges}}\">lista de modificationes recente</a> pro
 facilitar su identification.</p>
 
 <p>Si tu vole cessar le obsevation de iste pagina posteriormente, clicca \"Cancellar observation\" in le barra de navigation.",
@@ -825,7 +842,7 @@ specific que ha essite vandalisate).",
 "noblockreason" => "Tu debe fornir un motivo pro le blocage.",
 "blockipsuccesssub" => "Blocage con successo",
 "blockipsuccesstext" => "Le adresse IP \"$1\" ha essite blocate.
-<br>Vide [[Special:Ipblocklist|Lista de IPs blocate]] pro revider le blocages.",
+<br />Vide [[Special:Ipblocklist|Lista de IPs blocate]] pro revider le blocages.",
 "unblockip"		=> "Disblocar adresse IP",
 "unblockiptext"	=> "Usa le formulario infra pro restaurar le accesso de scriptura
 a un adresse de IP blocate previemente.",
@@ -858,7 +875,7 @@ Per favor confirma que iste es tu intention.",
 "lockdbsuccesssub" => "Base de datos blocate con successo",
 "unlockdbsuccesssub" => "Base de datos disblocate con successo",
 "lockdbsuccesstext" => "Le base de datos de Wikipedia ha essite blocate.
-<br>Rememora te de disblocar lo post completar tu mantenentia.",
+<br />Rememora te de disblocar lo post completar tu mantenentia.",
 "unlockdbsuccesstext" => "Le base de datos de Wikipedia ha essite disblocate.",
 
 # SQL query
@@ -903,7 +920,7 @@ Il tal casos, tu debera mover o fusionar le pagina manualmente si desirate.",
 "movearticle"	=> "Mover pagina",
 "movenologin"	=> "Session non aperte",
 "movenologintext" => "Tu debe esser un usator registrate e <a href=\"" .
-  wfLocalUrl( "Special:Userlogin" ) . "\">aperir un session</a>
+  "{{localurle:Special:Userlogin}}\">aperir un session</a>
 pro mover un pagina.",
 "newtitle"		=> "Al nove titulo",
 "movepagebtn"	=> "Mover pagina",
@@ -918,7 +935,16 @@ nove titulo. Per favor fusiona los manualmente.",
 "movedto"		=> "movite a",
 "movetalk"		=> "Mover le pagina de \"discussion\" tamben, si applicabile.",
 "talkpagemoved" => "Le pagina de discussion correspondente tamben ha essite movite.",
-"talkpagenotmoved" => "Le pagina de discussion correspondente <strong>non</strong> ha essite movite."
+"talkpagenotmoved" => "Le pagina de discussion correspondente <strong>non</strong> ha essite movite.",
+
+# Math
+
+	'mw_math_png' => "Sempre produce PNG",
+	'mw_math_simple' => "HTML si multo simple, alteremente PNG",
+	'mw_math_html' => "HTML si possibile, alteremente PNG",
+	'mw_math_source' => "Lassa lo como TeX (pro navigatores in modo texto)",
+	'mw_math_modern' => "Recommendate pro navigatores moderne",
+	'mw_math_mathml' => 'MathML',
 
 );
 
@@ -960,34 +986,6 @@ class LanguageIa extends LanguageUtf8 {
 		return $wgSkinNamesIa;
 	}
 
-	function getMathNames() {
-		global $wgMathNamesIa;
-		return $wgMathNamesIa;
-	}
-
-	function getUserToggles() {
-		global $wgUserTogglesIa;
-		return $wgUserTogglesIa;
-	}
-
-	function getMonthName( $key )
-	{
-		global $wgMonthNamesIa;
-		return $wgMonthNamesIa[$key-1];
-	}
-
-	function getMonthAbbreviation( $key )
-	{
-		global $wgMonthAbbreviationsIa;
-		return $wgMonthAbbreviationsIa[$key-1];
-	}
-
-	function getWeekdayName( $key )
-	{
-		global $wgWeekdayNamesIa;
-		return $wgWeekdayNamesIa[$key-1];
-	}
-
 	function date( $ts, $adj = false )
 	{
 		if ( $adj ) { $ts = $this->userAdjust( $ts ); }
