@@ -32,14 +32,6 @@ require_once( "LanguageUtf8.php" );
  "Обична", "Носталгија", "Келнско плаво", "Педингтон", "Монпарнас"
 );
 
-/* private */ $wgMathNamesSr = array(
- "Увек прикажи PNG",
- "HTML ако је врло једноставно, иначе PNG",
- "HTML ако је могуће, иначе PNG",
- "Остави као ТеХ (за текстуалне бровсере)",
- "Препоручено за савремене бровсере"
-);
-
 /* private */ $wgDateFormatsSr = array(
  "Без посебних жеља",
  "Јануар 15, 2001",
@@ -47,44 +39,7 @@ require_once( "LanguageUtf8.php" );
  "2001 Јануар 15"
 );
 
-/* private */ $wgUserTogglesSr = array(
- "hover"  => "Прикажи лебдећи текст изнад вики веза",
- "underline" => "Подвуци везе",
- "highlightbroken" => "Форматирај покварене везе <a href=\"\" class=\"new\">овако
-</a> (алтернатива: овако<a href=\"\" class=\"internal\">?</a>).",
- "justify" => "Поравнај пасусе",
- "hideminor" => "Сакриј мале измене у списку скорашњих променама",
- "usenewrc" => "Побољшана списку скорашњих промена (не за све бровсере)",
- "numberheadings" => "Аутоматски нумериши поднаслове",
-	"showtoolbar" => "Show edit toolbar",
- "editondblclick" => "Мењај странице двоструким кликом (захтева JavaScript)",
- "editsection"=>"Омогући измену делова [мењај] везама",
- "editsectiononrightclick"=>"Омогући измену делова десним кликом<br> на њихове наслове (захтева JavaScript)",
- "showtoc"=>"Прикажи садржај<br>(у свим чланцима са више од три поднаслова)",
- "rememberpassword" => "Памти шифру кроз више сеанси",
- "editwidth" => "Поље за измене има пуну ширину",
- "watchdefault" => "Додај странице које мењам у мој списак гледања",
- "minordefault" => "Означи све измене малим испрва",
- "previewontop" => "Покажи предпреглед пре поља за измену а не после њега",
- "nocache" => "Онемогући кеширање страница"
-);
 
-/* private */ $wgWeekdayNamesSr = array(
- "Недеља", "Понедељак", "Уторак", "Среда", "Четвртак",
- "Петак", "Субота"
-);
-
-/* private */ $wgMonthNamesSr = array(
- "Јануар", "Фебруар", "Март", "Април", "Мај", "Јуни",
- "Јули", "Август", "Септембар", "Октобар", "Новембар",
- "Децембар"
-);
-
-/* private */ $wgMonthAbbreviationsSr = array(
- "Јан", "Феб", "Мар", "Апр", "Мај", "Јун",
- "Јул", "Авг", "Сеп", "Окт", "Нов",
- "Дец"
-);
 
 /* NOT USED IN STABLE VERSION */
 /* private */ $wgMagicWordsSr = array(
@@ -158,6 +113,64 @@ require_once( "LanguageUtf8.php" );
 );
 
 /* private */ $wgAllMessagesSr = array(
+'special_version_prefix' => '',
+'special_version_postfix' => '',
+
+# User Toggles
+#
+"tog-hover"  => "Прикажи лебдећи текст изнад вики веза",
+"tog-underline" => "Подвуци везе",
+"tog-highlightbroken" => "Форматирај покварене везе <a href=\"\" class=\"new\">овако</a> (алтернатива: овако<a href=\"\" class=\"internal\">?</a>).",
+"tog-justify" => "Поравнај пасусе",
+"tog-hideminor" => "Сакриј мале измене у списку скорашњих променама",
+"tog-usenewrc" => "Побољшана списку скорашњих промена (не за све бровсере)",
+"tog-numberheadings" => "Аутоматски нумериши поднаслове",
+"tog-showtoolbar" => "Show edit toolbar",
+"tog-editondblclick" => "Мењај странице двоструким кликом (захтева JavaScript)",
+"tog-editsection"=>"Омогући измену делова [мењај] везама",
+"tog-editsectiononrightclick"=>"Омогући измену делова десним кликом<br /> на њихове наслове (захтева JavaScript)",
+"tog-showtoc"=>"Прикажи садржај<br />(у свим чланцима са више од три поднаслова)",
+"tog-rememberpassword" => "Памти шифру кроз више сеанси",
+"tog-editwidth" => "Поље за измене има пуну ширину",
+"tog-watchdefault" => "Додај странице које мењам у мој списак гледања",
+"tog-minordefault" => "Означи све измене малим испрва",
+"tog-previewontop" => "Покажи предпреглед пре поља за измену а не после њега",
+"tog-nocache" => "Онемогући кеширање страница",
+
+# Dates
+#
+
+'sunday' => "Недеља",
+'monday' => "Понедељак",
+'tuesday' => "Уторак",
+'wednesday' => "Среда",
+'thursday' => "Четвртак",
+'friday' => "Петак",
+'saturday' => "Субота",
+'january' => "Јануар",
+'february' => "Фебруар",
+'march' => "Март",
+'april' => "Април",
+'may_long' => "Мај",
+'june' => "Јуни",
+'july' => "Јули",
+'august' => "Август",
+'september' => "Септембар",
+'october' => "Октобар",
+'november' => "Новембар",
+'december' => "Децембар",
+'jan' => "Јан",
+'feb' => "Феб",
+'mar' => "Мар",
+'apr' => "Апр",
+'may' => "Мај",
+'jun' => "Јун",
+'jul' => "Јул",
+'aug' => "Авг",
+'sep' => "Сеп",
+'oct' => "Окт",
+'nov' => "Нов",
+'dec' => "Дец",
 
 # Bits of text used by many pages:
 #
@@ -170,7 +183,7 @@ require_once( "LanguageUtf8.php" );
 "mainpage"  => "Главна страна",
 "mainpagetext" => "Вики софтвер је успешно инсталиран.",
 "about"   => "О...",
-"aboutwikipedia" => "О Википедији",
+"aboutsite"      => "О Википедији",
 "aboutpage"  => "Википедија:О",
 "help"   => "Помоћ",
 "helppage"  => "Википедија:Помоћ",
@@ -193,7 +206,7 @@ require_once( "LanguageUtf8.php" );
 "currentevents" => "Тренутни догађаји",
 "errorpagetitle" => "Грешка",
 "returnto"  => "Повратак на $1.",
-"fromwikipedia" => "Из Википедије, слободне енциклопедије.",
+"tagline"       => "Из Википедије, слободне енциклопедије.",
 "whatlinkshere" => "Странице које су повезане овде",
 "help"   => "Помоћ",
 "search"  => "Тражи",
@@ -322,8 +335,8 @@ MySQL је вратио грешку \"$3: $4\".\n",
 "yourpasswordagain" => "Поново укуцајте шифру",
 "newusersonly" => " (само за нове кориснике)",
 "remembermypassword" => "Запамти моју шифру током више сеанси.",
-"loginproblem" => "<b>Било је проблема са вашим пријављивањем.</b><br>Пробајте поново!",
-"alreadyloggedin" => "<font color=red><b>Корисниче $1, већ сте пријављени!</b></font><br>\n",
+"loginproblem" => "<b>Било је проблема са вашим пријављивањем.</b><br />Пробајте поново!",
+"alreadyloggedin" => "<font color=red><b>Корисниче $1, већ сте пријављени!</b></font><br />\n",
 
 "login"   => "Пријави се",
 "userlogin"  => "Пријави се",
@@ -369,7 +382,7 @@ Sada biste trebali da se ulogujete i promenite svoju sifru.",
 "showpreview" => "Прикажи предпреглед",
 "blockedtitle" => "Корисник је блокиран",
 "blockedtext" => "Ваше корисничко име или ИП адреса је блокирана од стране $1.
-Дати разлог је следећи:<br>''$2''<p>Можете се обратити $1 или неком другом
+Дати разлог је следећи:<br />''$2''<p>Можете се обратити $1 или неком другом
 [[Википедија:администратори|администратору]] да бисте разговарали о блокади.",
 "whitelistedittitle" => "Обавезно је пријављивање за мењање",
 "whitelistedittext" => "Морате да се [[Посебно:Пријављивање|пријавите]] да бисте мењали чланке.",
@@ -393,8 +406,8 @@ Sada biste trebali da se ulogujete i promenite svoju sifru.",
 "previewconflict" => "Овај предпреглед осликава како ће текст у
 текстуалном пољу изгледати ако се одлучите да га снимите.",
 "editing"  => "Мењам $1",
-"sectionedit" => " (део)",
-"commentedit" => " (коментар)",
+"editingsection"  => "Мењам $1 (део)",
+"editingcomment"  => "Мењам $1 (коментар)",
 "editconflict" => "Сукобљене измене: $1",
 "explainconflict" => "Неко други је променио ову страницу откад сте ви почели да је мењате.
 Горње текстуално поље садржи текст странице какв тренутно постоји.
@@ -412,7 +425,7 @@ Sada biste trebali da se ulogujete i promenite svoju sifru.",
 сматра да је објављен под ГНУ лиценцом за слободну документацију
 (погледајте $1 за детаље).
 Ако не желите да се ваше писање мења и редистрибуира
-без ограничења, онда га немојте слати овде.<br>
+без ограничења, онда га немојте слати овде.<br />
 Такође нам обећавате да сте га сами написали, или ископирали из
 извора који је у јавном власништву или сличног слободног извора.
 <strong>НЕ ШАЉИТЕ РАД ЗАШТИЋЕН АУТОРСКИМ ПРАВИМА БЕЗ ДОЗВОЛЕ!</strong>",
@@ -453,9 +466,7 @@ Sada biste trebali da se ulogujete i promenite svoju sifru.",
 # Search results
 #
 "searchresults" => "Резултати претраге",
-"searchhelppage" => "Википедија:Тражење",
-"searchingwikipedia" => "Претраживање Википедије",
-"searchresulttext" => "За више информација о претраживању Википедије, погледајте $1.",
+"searchresulttext" => "За више информација о претраживању Википедије, погледајте [[Википедија:Тражење|Претраживање Википедије]].",
 "searchquery" => "За упит \"$1\"",
 "badquery"  => "Лоше обликован упит за претрагу",
 "badquerytext" => "Нисмо могли да обрадимо ваш упит.
@@ -482,31 +493,12 @@ Sada biste trebali da se ulogujete i promenite svoju sifru.",
 које садрже све изразе који се траже ће се појавити у резултату).",
 "powersearch" => "Тражи",
 "powersearchtext" => "
-Претрага и уменским просторима:<br>
-$1<br>
+Претрага и уменским просторима:<br />
+$1<br />
 $2 Излистај преусмерења &nbsp; Тражи $3 $9",
 "searchdisabled" => "<p>Жалимо! Пуна претрага текста је привремено онемогућена, због бржег рада Википедије. Умеђувремену, можете користити Гугле претрагу испод, која може бити застарела.</p>
 
 ",
-"googlesearch" => "<!-- SiteSearch Google -->
-<FORM method=GET action=\"http://www.google.com/search\">
-<TABLE bgcolor=\"#FFFFFF\"><tr><td>
-<A HREF=\"http://www.google.com/\">
-<IMG SRC=\"http://www.google.com/logos/Logo_40wht.gif\"
-border=\"0\" ALT=\"Google\"></A>
-</td>
-<td>
-<INPUT TYPE=hidden name=hl value=sr>
-<INPUT TYPE=hidden name=ie value=UTF-8>
-<INPUT TYPE=hidden name=oe value=UTF-8>
-<INPUT TYPE=text name=q size=31 maxlength=255 value=\"\">
-<INPUT type=submit name=btnG VALUE=\"Гугле претрага\">
-<font size=-1>
-<input type=hidden name=domains value=\"{$wgServer}\"><br><input type=radio name=sitesearch value=\"\"> WWW <input type=radio name=sitesearch value=\"{$wgServer}\" checked> {$wgServer} <br>
-</font>
-</td></tr></TABLE>
-</FORM>
-<!-- SiteSearch Google -->",
 "blanknamespace" => "(Главно)",
 
 # Preferences page
@@ -514,7 +506,7 @@ border=\"0\" ALT=\"Google\"></A>
 "preferences" => "Подешавања",
 "prefsnologin" => "Нисте пријављени",
 "prefsnologintext" => "Морате бити <a href=\"" .
-  wfLocalUrl( "Special:Userlogin" ) . "\">пријављени</a>
+  "{{localurle:Special:Userlogin}}\">пријављени</a>
 да бисте подешавали корисничка подешавања.",
 "prefslogintext" => "Пријављени сте као \"$1\".
 Ваш интерни ИД број је $2.
@@ -604,19 +596,20 @@ border=\"0\" ALT=\"Google\"></A>
 "reuploaddesc" => "Врати се на упитник за слање.",
 "uploadnologin" => "Нисте пријављени",
 "uploadnologintext" => "Морате бити <a href=\"" .
-  wfLocalUrl( "Special:Userlogin" ) . "\">пријављени</a>
+  "{{localurle:Special:Userlogin}}\">пријављени</a>
 да бисте слали фајлове.",
 "uploadfile" => "Пошаљи слике, звуке, документа итд.",
 "uploaderror" => "Грешка при слању",
-"uploadtext" => "<strong>СТОП!</strong> Пре него што шаљете овде,
-обавезно прочитајте и пратите Википедијина <a href=\"" .
-wfLocalUrlE( "Wikipedia:Image_use_policy" ) . "\">правила коришћења слика</a>.
-<p>Да бисте прегледали или претраживали раније послате слике,
-идите на <a href=\"" . wfLocalUrlE( "Special:Imagelist" ) .
-"\">списак послатих слика</a>.
-Слања и брисања су логована на <a href=\"" .
-wfLocalUrlE( "Wikipedia:Upload_log" ) . "\">логу слања</a>.
-<p>Употребите доњи упитник да бисте послали нове слике за
+"uploadtext" => "'''СТОП!''' Пре него што шаљете овде,
+обавезно прочитајте и пратите Википедијина
+[[Project:Image_use_policy|правила коришћења слика]].
+
+Да бисте прегледали или претраживали раније послате слике,
+идите на [[Special:Imagelist|списак послатих слика]].
+Слања и брисања су логована на
+[[Project:Upload_log|логу слања]].
+
+Употребите доњи упитник да бисте послали нове слике за
 илустровање својих чланака.
 На већини бровсера, видећете \"Browse...\" дугме, које ће вам
 отворити стандардни прозор вашег оперативног система за бирање фајла.
@@ -626,13 +619,15 @@ wfLocalUrlE( "Wikipedia:Upload_log" ) . "\">логу слања</a>.
 повређујете никаква ауторска права слањем фајла.
 Притисните дугме \"Пошаљи\" да бисте завршили слање.
 Оно може потрајати ако имате спору Интернет везу.
-<p>Пожељни формати су JPEG за фотографије, PNG
+
+Пожељни формати су JPEG за фотографије, PNG
 за цртеже и остале једноставне слике, и OGG за звуке.
 Молимо вас да имена ваших фајлова имају неко значење да бисте избегли забуну.
 Да бисте укључили слику у текст, употребите везу у облику
-<b>[[image:file.jpg]]</b> или <b>[[image:file.png|алтернативни текст]]</b>
-or <b>[[media:file.ogg]]</b> за звукове.
-<p>Обратите пажњу да, као и код Википедијиних страница, други могу мењати или
+'''<nowiki>[[image:file.jpg]]</nowiki>''' или '''<nowiki>[[image:file.png|алтернативни текст]]</nowiki>'''
+or '''<nowiki>[[media:file.ogg]]</nowiki>''' за звукове.
+
+Обратите пажњу да, као и код Википедијиних страница, други могу мењати или
 избрисати ваша слања ако мисле да то користи енциклопедији, а
 може вам се и забранити да шаљете ако злоупотребите систем.",
 "uploadlog"  => "лог слања",
@@ -688,7 +683,7 @@ or <b>[[media:file.ogg]]</b> за звукове.
 "deleteimgcompletely"  => "обр",
 "imghistlegend" => "Објашњење: (трен) = ово је тренутна слика, (обр) = обриши
 ову стару верзију, (врт) = врати на ову стару верзију.
-<br><i>Кликните на датум давидите слику послату тог датума</i>.",
+<br /><i>Кликните на датум давидите слику послату тог датума</i>.",
 "imagelinks" => "Употреба слике",
 "linkstoimage" => "Следеће странице користе на ову слику:",
 "nolinkstoimage" => "Нема страница које користе ову слику.",
@@ -716,9 +711,9 @@ or <b>[[media:file.ogg]]</b> за звукове.
 "maintenancebacklink" => "Назад на страницу за одржавање",
 "disambiguations" => "Странице за обездвосмишљење",
 "disambiguationspage" => "Википедија:Линкови_на_странице_за_обезвосмишљење",
-"disambiguationstext" => "Следећи чланци се повезују са <i>страницом за обездвосмишљење</i>. Уместо тога, они би требали да се повезују са одговарајућом темом.<br>Страница се третира као обездвосмишљенска ако је повезана са $1.<br>Линкови из осталих именских простора <i>нису</i> наведени овде.",
+"disambiguationstext" => "Следећи чланци се повезују са <i>страницом за обездвосмишљење</i>. Уместо тога, они би требали да се повезују са одговарајућом темом.<br />Страница се третира као обездвосмишљенска ако је повезана са $1.<br />Линкови из осталих именских простора <i>нису</i> наведени овде.",
 "doubleredirects" => "Двострука преусмерења",
-"doubleredirectstext" => "<b>Пажња:</b> Овај списак може да садржи лажне резултате. То обично значи да постоји додатни текст са везама испод првог #REDIRECT.<br>\nСваки ред садржи везе на прво и друго преусмерење, као и на прву линију текста другог преусмерења, што обично даје \"прави\" циљни чланак, на који би прво преусмерење и требало да показује.",
+"doubleredirectstext" => "<b>Пажња:</b> Овај списак може да садржи лажне резултате. То обично значи да постоји додатни текст са везама испод првог #REDIRECT.<br />\nСваки ред садржи везе на прво и друго преусмерење, као и на прву линију текста другог преусмерења, што обично даје \"прави\" циљни чланак, на који би прво преусмерење и требало да показује.",
 "brokenredirects" => "Покварена преусмерења",
 "brokenredirectstext" => "Следећа преусмерења су повезана на непостојећи чланак.",
 "selflinks"  => "Странице са самовезама",
@@ -773,9 +768,9 @@ or <b>[[media:file.ogg]]</b> за звукове.
 #
 "mailnologin" => "Нема адресе за слање",
 "mailnologintext" => "Морате бити <a href=\"" .
-  wfLocalUrl( "Special:Userlogin" ) . "\">пријављени</a>
+  "{{localurle:Special:Userlogin}}\">пријављени</a>
 и имати исправну е-адресу in your <a href=\"" .
-  wfLocalUrl( "Special:Preferences" ) . "\">подешавањима</a>
+  "{{localurle:Special:Preferences}}\">подешавањима</a>
 да бисте слали електронску пошту другим корисницима.",
 "emailuser"  => "Пошаљи е-писмо овом кориснику",
 "emailpage"  => "Пошаљи е-писмо кориснику",
@@ -802,14 +797,14 @@ or <b>[[media:file.ogg]]</b> за звукове.
 "nowatchlist" => "Немате ништа на свом списку надгледања.",
 "watchnologin" => "Нисте пријављени",
 "watchnologintext" => "Морате бити <a href=\"" .
-  wfLocalUrl( "Special:Userlogin" ) . "\">пријављени</a>
+  "{{localurle:Special:Userlogin}}\">пријављени</a>
 да бисте мењали списак надгледања.",
 "addedwatch" => "Додати списку надгледања",
 "addedwatchtext" => "Страница \"$1\" је додата вашој <a href=\"" .
-  wfLocalUrl( "Special:Watchlist" ) . "\">списку надгледања</a>.
+  "{{localurle:Special:Watchlist}}\">списку надгледања</a>.
 Будуће промене ове странице и њој придружене странице за разговор ће бити наведене овде,
 и страница ће бити <b>подебљана</b> у <a href=\"" .
-  wfLocalUrl( "Special:Recentchanges" ) . "\">списку скорашњих измена</a> да
+  "{{localurle:Special:Recentchanges}}\">списку скорашњих измена</a> да
 би се лакше уочила.</p>
 
 <p>Ако касније желите да уклоните страницу са вашег списка надгледања, кликните на \"Прекини надгледање\" на бочној палети.",
@@ -934,7 +929,7 @@ $3...
 "noblockreason" => "Морате дати разлог за обуздавање.",
 "blockipsuccesssub" => "Обуздавање је успело",
 "blockipsuccesstext" => "\"$1\" је обуздан.
-<br>Погледајте [[Посебно:ИПсписакаобузданих|ИП списак обузданих]] за преглед обуздавања.",
+<br />Погледајте [[Посебно:ИПсписакаобузданих|ИП списак обузданих]] за преглед обуздавања.",
 "unblockip"  => "Отпусти корисника",
 "unblockiptext" => "Употребите доњи упитник да бист вратили право писања
 раније обузданој ИП адреси или корисничком имену.",
@@ -973,7 +968,7 @@ $3...
 "lockdbsuccesssub" => "База је закључана",
 "unlockdbsuccesssub" => "База је откључана",
 "lockdbsuccesstext" => "Википедијина база података је закључана.
-<br>Сетите се да је откључате када завршите са одржавањем.",
+<br />Сетите се да је откључате када завршите са одржавањем.",
 "unlockdbsuccesstext" => "Википедијина база података је откључана.",
 
 # SQL query
@@ -1021,7 +1016,7 @@ $3...
 "movearticle" => "Премести страницу",
 "movenologin" => "Нисте улоговани",
 "movenologintext" => "Морате бити регистровани корисник и <a href=\"" .
-  wfLocalUrl( "Special:Userlogin" ) . "\">пријављени</a>
+  "{{localurle:Special:Userlogin}}\">пријављени</a>
 да бисте преместили страницу.",
 "newtitle"  => "Нови наслов",
 "movepagebtn" => "премести страницу",
@@ -1047,7 +1042,16 @@ $3...
 # Namespace 8 related
 
 "allmessages" => "Све_поруке",
-"allmessagestext" => "Ово је списак свих порука које су у МедијаВики: именском простору"
+"allmessagestext" => "Ово је списак свих порука које су у МедијаВики: именском простору",
+
+# Math
+
+ 'mw_math_png' => "Увек прикажи PNG",
+ 'mw_math_simple' => "HTML ако је врло једноставно, иначе PNG",
+ 'mw_math_html' => "HTML ако је могуће, иначе PNG",
+ 'mw_math_source' => "Остави као ТеХ (за текстуалне бровсере)",
+ 'mw_math_modern' => "Препоручено за савремене бровсере",
+
 );
 
 #--------------------------------------------------------------------------
@@ -1088,46 +1092,11 @@ class LanguageSr extends LanguageUtf8 {
   return $wgSkinNamesSr;
  }
 
- function getMathNames() {
-  global $wgMathNamesSr;
-  return $wgMathNamesSr;
- }
- 
  function getDateFormats() {
   global $wgDateFormatsSr;
   return $wgDateFormatsSr;
  }
 
- function getUserToggles() {
-  global $wgUserTogglesSr;
-  return $wgUserTogglesSr;
- }
-
- function getMonthName( $key )
- {
-  global $wgMonthNamesSr;
-  return $wgMonthNamesSr[$key-1];
- }
- 
- /* by default we just return base form */
- function getMonthNameGen( $key )
- {
-  global $wgMonthNamesSr;
-  return $wgMonthNamesSr[$key-1];
- }
- 
- function getMonthAbbreviation( $key )
- {
-  global $wgMonthAbbreviationsSr;
-  return $wgMonthAbbreviationsSr[$key-1];
- }
-
- function getWeekdayName( $key )
- {
-  global $wgWeekdayNamesSr;
-  return $wgWeekdayNamesSr[$key-1];
- }
-
  function getValidSpecialPages()
  {
   global $wgValidSpecialPagesSr;
