@@ -2,7 +2,7 @@
 -- used from 2003-08-21 dev version.
 -- Import the default mappings from maintenance/interwiki.sql
 
-CREATE TABLE interwiki (
+CREATE TABLE /*$wgDBprefix*/interwiki (
   iw_prefix char(32) NOT NULL,
   iw_url char(127) NOT NULL,
   iw_local BOOL NOT NULL,
